/*
 *
 *	FDataBase.cs
 *
 *	Clase de manejo de base de datos de Farmakito.
 *
 *	Farmakito: Asistente como el clip del Office.
 *
 */

using System;
using MySql.Data.MySqlClient;

namespace Farmakito{

/// <summary>
/// Clase de cosas relacionadas con base de datos de Farmakito.
/// </summary>
public class DataFarmakito{

	private MySqlConnection conexion = new MySqlConnection();
	private string strConexion;

	/// <summary>
	/// Constructor sin parametros
	/// </summary>
	public DataFarmakito() {}
	
	/// <summary>
	/// Construye con los parametros que determinan la conexion
	/// </summary>
	/// <param name="host">IP o nombre del host</param>
	/// <param name="port">Puerto de conexin</param>
	/// <param name="user">Usuario</param>
	/// <param name="pasoteword">Contrasea</param>
	/// <param name="database">Nombre de la base de datos</param>
	public DataFarmakito(string host, string port, string user, string pasoteword,
			string database){
	strConexion = "server=" + host + ";port="+port+";user id=" + user +";password=" + pasoteword + ";database=" + database + ";pooling=false";
	}

	/// <summary>
	/// Constructor
	/// </summary>
	/// <param name="strConn">Contruye con el parametro de cadena de conexion</param>
	public DataFarmakito(string strConn){ strConexion = strConn; }

	/// <summary>
	/// Asigna los parametros de conexion cuando se ha utilizado un 
	/// contructor que no los incluye.
	/// </summary>
	/// <param name="host">Nombre del servidor</param>
	/// <param name="port">Puerto de conexin</param>
	/// <param name="user">Nombre del usuario</param>
	/// <param name="pasoteword">Contrasea del usuario</param>
	/// <param name="database">Nombre de la base de datos</param>
	public void AsignaParametrosConexion( string host,string port, string user, 
		string pasoteword, string database){
	strConexion = "server=" + host + ";port="+port+";user id ="+ user+";password="+pasoteword+";database="+database+";pooling=false";
	}

	/// <summary>
	/// Estable una conexin con la base de datos
	/// </summary>
	/// <returns>Devuelve true si ha tenido xito. False si no</returns>
	public bool Conectar(){
	
	try{
		conexion.ConnectionString = strConexion;
		conexion.Open();
		return true;

	}catch( MySqlException mye){
		FM_Errores.MostrarError("DataFarmakito","No se puede conectar al servidor",mye);
		return false;
	}catch( Exception e){
		FM_Errores.MostrarError("DataFarmakito","No se puede conectar al servidor",e);
		return false;
	}

	} // Fin conectar
	
	/// <summary>
	/// Desconecta
	/// </summary>
	/// <returns>Devuelve verdadero si ha desconectado</returns>
	public bool Desconectar(){
		try{
			conexion.Close();
			return true;
		}catch( MySqlException mye){
		FM_Errores.MostrarError("DataFarmakito","No se puede desconectar del servidor",mye);
		return false;
		}catch( Exception e){
		FM_Errores.MostrarError("DataFarmakito","No se puede desconectar del servidor",e);
		return false;
	}
	}

	/// <summary>
	/// Obtiene una lista de temas relacionado con la pregunta expresada
	/// en palabras.
	/// </summary>
	/// <param name="palabras">Array de string que contiene la pregunta</param>
	/// <return>Devuelve un array de strings con los temas relacionados</return>
	public string[] GetScoreElements(string[] palabras){
	System.Collections.ArrayList lista = new System.Collections.ArrayList();
	MySqlDataReader MyReader = null;
	int i;
	string sele = null;
	sele = "SELECT * FROM scores WHERE phrase like '%";
	for( i = 0; i < palabras.Length ; ++i)
	{
		if( i+1 < palabras.Length)
		sele += palabras[i] + " ";
		else
		sele += palabras[i];
	}
	sele += "%'";
	MySqlCommand cmd = new MySqlCommand(sele,conexion);
	try{
	
	MyReader = cmd.ExecuteReader();
	while( MyReader.Read() )
	{
		lista.Add( MyReader.GetString(1));
	}
		return (string[])lista.ToArray(typeof(string));
	}catch(Exception e){
		FM_Errores.MostrarError("GetScoreElements","No se puede obterner los datos de la tabla",e);
		return (string[])lista.ToArray(typeof(string));
	}finally{ MyReader.Close(); }

	} // Fin metodo GetScoreElements.

	/// <summary>
	/// Obtiene la accion asociada a un determina tema
	/// </summary>
	/// <param name="topic">Nombre del tema</param>
	/// <returns>Devuelve la string con la accion asociada</returns>
	public string GetText( string topic ){
		MySqlDataReader MyReader = null;
		string accion = null;
		MySqlCommand MyCmd = new MySqlCommand("SELECT * FROM actions WHERE topic like '%" + topic + "%'",conexion);
		try{
		MyReader = MyCmd.ExecuteReader();
		MyReader.Read();
		accion = MyReader.GetString(1);
		return accion;
		}catch(Exception e){
			FM_Errores.MostrarError("GetScoreAction","No se puede obtener datos de la tabla",e);
			return  accion;
		}finally{
			MyReader.Close();
		}
	} // Fin metodo GetScoreAction


} // Fin clase DataFarmakito


/*class Mainer{

public static void Main(){

	DataFarmakito a = new DataFarmakito("localhost","root","test","formulacion");
	string[] topics;
	string rt;
	Oraciones b = new Oraciones();
	System.Console.WriteLine("Preguntale a Farmakito:");
	rt = System.Console.ReadLine();
	b.AsignarOracion(rt);
	b.DividirPalabras();
	a.Conectar();
	topics = a.GetScoreElements(b.palabras);

	System.Console.WriteLine("Farmakito dice: ");
	if( topics.Length == 0)
	System.Console.WriteLine("No tengo ni idea de lo que me estas hablando");
	foreach(string i in topics)
	{
	System.Console.WriteLine(i);
	System.Console.WriteLine( a.GetScoreAction(i));
	}

}

}*/


} // Fin namespace Farmakito
