/*
 * 
 * MateriasForm
 * 
 * 
 * (C) Alvaro Cortes. 2007. alvarocortesc@gmail.com
 * 
 * 
 * Gestion de Materias Primas por separado de modulo principal
 * 
 */

using System;
using System.Drawing;
using System.Windows.Forms;

using System.Drawing.Printing;
using MySql.Data.MySqlClient;
using System.Data;

namespace FormulacionMagistral
{
	/// <summary>
	/// Description of MateriasForm.
	/// </summary>
	public class MateriasForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.TextBox txtProveedorID;
		private System.Windows.Forms.Label lblCantidad;
		private System.Windows.Forms.Label lblAceptacionID;
		private System.Windows.Forms.Label lblControlID;
		private System.Windows.Forms.Label lblFechaRecepcion;
		private System.Windows.Forms.TextBox txtAceptacionID;
		private System.Windows.Forms.Button btnFirst;
		private System.Windows.Forms.Button btnPrev;
		private System.Windows.Forms.Label lblPos;
		private System.Windows.Forms.Button btnBorrar;
		private System.Windows.Forms.TextBox txtControlID;
		private System.Windows.Forms.Label lblFechaCaducidad;
		private System.Windows.Forms.Button btnImprimirFicha;
		private System.Windows.Forms.Label lblMateriaID;
		private System.Windows.Forms.TextBox txtCantidad;
		private System.Windows.Forms.Label lblDOE;
		private System.Windows.Forms.TextBox txtFechaCaducidad;
		private System.Windows.Forms.Label lblLote;
		private System.Windows.Forms.TextBox txtNEnvases;
		private System.Windows.Forms.Button btnLast;
		private System.Windows.Forms.TextBox txtRegistroID;
		private System.Windows.Forms.Button btnGuardar;
		private System.Windows.Forms.Button btnProveedor;
		private System.Windows.Forms.TextBox txtLote;
		private System.Windows.Forms.Label lblRegistroID;
		private System.Windows.Forms.Label lblProveedorID;
		private System.Windows.Forms.Button btnNext;
		private System.Windows.Forms.Button btnImprimirListado;
		private System.Windows.Forms.Button btnControlID;
		private System.Windows.Forms.Button btnAceptaciones;
		private System.Windows.Forms.Button btnSelectMateria;
		private System.Windows.Forms.Label lblNEnvases;
		private System.Windows.Forms.TextBox txtDOE;
		private System.Windows.Forms.TextBox txtFechaRecepcion;
		private System.Windows.Forms.Button btnNuevo;
		private System.Windows.Forms.TextBox txtMateriaID;
		
		
		private MySqlConnection conn;
		private MySqlDataAdapter adap;  
		private System.Data.DataSet ds;
		private MySqlParameter parm;
		
	
		// Algunas variables para emular el CurrencyManager defectuoso de Mono
		private int RecCount;
		private int RecPosition;
				
		// Para cargar preferencias de la BD
		private Formulacion.PreferenciasDB DBPrefs;
		
		// Informacion para conexion BD
		private string dbhost;
		private string dbport;
		private string dbuser;
		private string dbpasoteword;
		
		
		
		// Nivel de acceso
		private int currentlevel;
		private Alertas AlertaLocal; // Alertas

		
		
		/// <summary>
		/// Constructor 
		/// </summary>
		/// <param name="nivel">Nivel de autorizacion</param>
		public MateriasForm(int nivel)
		{
			//
			// The InitializeComponent() call is required for Windows Forms designer support.
			//
			InitializeComponent();
			
			this.currentlevel = nivel;
			
			DBPrefs = new Formulacion.PreferenciasDB();
			DBPrefs.AsignarNmbFichero("PrefDataBase.xml");
			
			AlertaLocal = new Alertas();

			
		}
		
		/// <summary>
		/// Obtiene el id del registro actual
		/// </summary>
		/// <returns>Devuelve un entero del ID del registro</returns>
		public int getcurrentid(){
			int n;
			try{
				n = Convert.ToInt32( this.txtMateriaID.Text);
				return n;
			}catch(Exception ex){
				FM_Errores.MostrarError("GetCurrentID","No se puede obtener el ID actual",ex);
				return -1;
			}
		}
		
		
		/// <summary>
		/// Carga la configuracin de la base de datos en la vars
		/// de la clase
		/// </summary>
		void CargarConfiguracionDatabase(){
			string[] prf;
			if ( this.DBPrefs.LeerFichero() )
			{
				prf = this.DBPrefs.CargarPreferenciasDB();
				
				for( int i = 0; i < prf.Length; ++i)
				{
					switch(i){
						case 0: this.dbhost = prf[0]; break;
						case 1: this.dbport = prf[1]; break;
						case 3: this.dbuser = prf[2]; break;
						case 4: this.dbpasoteword = prf[3]; break;
					
					}
				}
				this.DBPrefs.CerrarEntrada();
			}
		}
		
		
		private bool Conectar(){
			try{
		 	conn = new MySqlConnection("host="+this.dbhost+";port=" + this.dbport + ";user id="+this.dbuser+";password="+this.dbpasoteword+ ";database=formulacion");

		 	adap = new MySqlDataAdapter();
			ds = new System.Data.DataSet();
			
		 	adap.SelectCommand = new MySqlCommand("SELECT * FROM registro;",conn);
			adap.Fill(ds,"Registro");
		 	
		 	return true;
			}catch(MySqlException ex){
				FM_Errores.MostrarError("MateriasRegistroForm","Error relacionado con base de datos",ex);
				return false;
			}catch(Exception e){
				FM_Errores.MostrarError("MateriasRegistroForm","Error general. No se puede cargar la informacion del registro de materias primas",e);
				return false;
			}
		 	
		}

		private void CargarComandoUpdate(){
			adap.UpdateCommand = new MySqlCommand("Update registro Set RegistroID = ?RegistroID, ProveedorID=?ProveedorID, MateriaID=?MateriaID, Lote=?Lote, ControlID=?ControlID, FechaRecepcion=?FechaRecepcion, Cantidad=?Cantidad, NEnvases=?NEnvases, FechaCaducidad=?FechaCaducidad, AceptacionID=?AceptacionID WHERE RegistroID = ?RegistroIDA",conn);
			
			parm = adap.UpdateCommand.Parameters.Add("?RegistroIDA", MySqlDbType.Int32);
			parm.SourceColumn = "RegistroID";
			parm.SourceVersion = DataRowVersion.Original;

			parm = adap.UpdateCommand.Parameters.Add("?RegistroID", MySqlDbType.Int32);
			parm.SourceColumn = "RegistroID";
			parm.SourceVersion = DataRowVersion.Current;
							
			parm = adap.UpdateCommand.Parameters.Add("?MateriaID", MySqlDbType.Int32);
			parm.SourceColumn = "MateriaID";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.UpdateCommand.Parameters.Add("?ProveedorID", MySqlDbType.Int32);
			parm.SourceColumn = "ProveedorID";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.UpdateCommand.Parameters.Add("?Lote", MySqlDbType.VarChar, 30);
			parm.SourceColumn = "Lote";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.UpdateCommand.Parameters.Add("?ControlID", MySqlDbType.Int32);
			parm.SourceColumn = "ControlID";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.UpdateCommand.Parameters.Add("?FechaRecepcion", MySqlDbType.VarChar, 45);
			parm.SourceColumn = "FechaRecepcion";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.UpdateCommand.Parameters.Add("?Cantidad", MySqlDbType.Float);
			parm.SourceColumn = "Cantidad";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.UpdateCommand.Parameters.Add("?NEnvases", MySqlDbType.Int32);
			parm.SourceColumn = "NEnvases";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.UpdateCommand.Parameters.Add("?FechaCaducidad", MySqlDbType.VarChar, 45);
			parm.SourceColumn = "FechaCaducidad";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.UpdateCommand.Parameters.Add("?AceptacionID", MySqlDbType.Int32);
			parm.SourceColumn = "AceptacionID";
			parm.SourceVersion = DataRowVersion.Current;
			
		}
		
		private void CargarComandoDelete(){
			adap.DeleteCommand = new MySqlCommand("DELETE FROM registro WHERE RegistroID = ?RegistroID",conn);
			
			parm = adap.DeleteCommand.Parameters.Add("?RegistroID", MySqlDbType.Int32);
			parm.SourceColumn = "RegistroID";
			parm.SourceVersion = DataRowVersion.Original;
			
		}
		
		private void CargarComandoInsert(){
			adap.InsertCommand = new MySqlCommand("Insert into registro(RegistroID, MateriaID, ProveedorID, Lote, ControlID, FechaRecepcion, Cantidad, NEnvases, FechaCaducidad, AceptacionID) VALUES (?RegistroID, ?MateriaID, ?ProveedorID, ?Lote, ?ControlID, ?FechaRecepcion, ?Cantidad, ?NEnvases, ?FechaCaducidad, ?AceptacionID)",conn);

			parm = adap.InsertCommand.Parameters.Add("?RegistroID", MySqlDbType.Int32);
			parm.SourceColumn = "RegistroID";
			parm.SourceVersion = DataRowVersion.Current;
							
			parm = adap.InsertCommand.Parameters.Add("?MateriaID", MySqlDbType.Int32);
			parm.SourceColumn = "MateriaID";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.InsertCommand.Parameters.Add("?ProveedorID", MySqlDbType.Int32);
			parm.SourceColumn = "ProveedorID";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.InsertCommand.Parameters.Add("?Lote", MySqlDbType.VarChar, 30);
			parm.SourceColumn = "Lote";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?ControlID", MySqlDbType.Int32);
			parm.SourceColumn = "ControlID";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.InsertCommand.Parameters.Add("?FechaRecepcion", MySqlDbType.VarChar, 45);
			parm.SourceColumn = "FechaRecepcion";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.InsertCommand.Parameters.Add("?Cantidad", MySqlDbType.Float);
			parm.SourceColumn = "Cantidad";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?NEnvases", MySqlDbType.Int32);
			parm.SourceColumn = "NEnvases";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.InsertCommand.Parameters.Add("?FechaCaducidad", MySqlDbType.VarChar, 45);
			parm.SourceColumn = "FechaCaducidad";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.InsertCommand.Parameters.Add("?AceptacionID", MySqlDbType.Int32);
			parm.SourceColumn = "AceptacionID";
			parm.SourceVersion = DataRowVersion.Current;
		}

		
		
		
		#region Windows Forms Designer generated code
		/// <summary>
		/// This method is required for Windows Forms designer support.
		/// Do not change the method contents inside the source code editor. The Forms designer might
		/// not be able to load this method if it was changed manually.
		/// </summary>
		private void InitializeComponent() {
			this.txtMateriaID = new System.Windows.Forms.TextBox();
			this.btnNuevo = new System.Windows.Forms.Button();
			this.txtFechaRecepcion = new System.Windows.Forms.TextBox();
			this.txtDOE = new System.Windows.Forms.TextBox();
			this.lblNEnvases = new System.Windows.Forms.Label();
			this.btnSelectMateria = new System.Windows.Forms.Button();
			this.btnAceptaciones = new System.Windows.Forms.Button();
			this.btnControlID = new System.Windows.Forms.Button();
			this.btnImprimirListado = new System.Windows.Forms.Button();
			this.btnNext = new System.Windows.Forms.Button();
			this.lblProveedorID = new System.Windows.Forms.Label();
			this.lblRegistroID = new System.Windows.Forms.Label();
			this.txtLote = new System.Windows.Forms.TextBox();
			this.btnProveedor = new System.Windows.Forms.Button();
			this.btnGuardar = new System.Windows.Forms.Button();
			this.txtRegistroID = new System.Windows.Forms.TextBox();
			this.btnLast = new System.Windows.Forms.Button();
			this.txtNEnvases = new System.Windows.Forms.TextBox();
			this.lblLote = new System.Windows.Forms.Label();
			this.txtFechaCaducidad = new System.Windows.Forms.TextBox();
			this.lblDOE = new System.Windows.Forms.Label();
			this.txtCantidad = new System.Windows.Forms.TextBox();
			this.lblMateriaID = new System.Windows.Forms.Label();
			this.btnImprimirFicha = new System.Windows.Forms.Button();
			this.lblFechaCaducidad = new System.Windows.Forms.Label();
			this.txtControlID = new System.Windows.Forms.TextBox();
			this.btnBorrar = new System.Windows.Forms.Button();
			this.lblPos = new System.Windows.Forms.Label();
			this.btnPrev = new System.Windows.Forms.Button();
			this.btnFirst = new System.Windows.Forms.Button();
			this.txtAceptacionID = new System.Windows.Forms.TextBox();
			this.lblFechaRecepcion = new System.Windows.Forms.Label();
			this.lblControlID = new System.Windows.Forms.Label();
			this.lblAceptacionID = new System.Windows.Forms.Label();
			this.lblCantidad = new System.Windows.Forms.Label();
			this.txtProveedorID = new System.Windows.Forms.TextBox();
			this.SuspendLayout();
			// 
			// txtMateriaID
			// 
			this.txtMateriaID.Enabled = false;
			this.txtMateriaID.Location = new System.Drawing.Point(440, 152);
			this.txtMateriaID.Name = "txtMateriaID";
			this.txtMateriaID.Size = new System.Drawing.Size(176, 20);
			this.txtMateriaID.TabIndex = 34;
			this.txtMateriaID.Text = "";
			// 
			// btnNuevo
			// 
			this.btnNuevo.Location = new System.Drawing.Point(440, 216);
			this.btnNuevo.Name = "btnNuevo";
			this.btnNuevo.Size = new System.Drawing.Size(104, 24);
			this.btnNuevo.TabIndex = 23;
			this.btnNuevo.Text = "Nuevo";
			this.btnNuevo.Click += new System.EventHandler(this.BtnNuevoClick);
			// 
			// txtFechaRecepcion
			// 
			this.txtFechaRecepcion.Location = new System.Drawing.Point(440, 120);
			this.txtFechaRecepcion.Name = "txtFechaRecepcion";
			this.txtFechaRecepcion.Size = new System.Drawing.Size(176, 20);
			this.txtFechaRecepcion.TabIndex = 15;
			this.txtFechaRecepcion.Text = "";
			// 
			// txtDOE
			// 
			this.txtDOE.Enabled = false;
			this.txtDOE.Location = new System.Drawing.Point(128, 56);
			this.txtDOE.Name = "txtDOE";
			this.txtDOE.Size = new System.Drawing.Size(176, 20);
			this.txtDOE.TabIndex = 11;
			this.txtDOE.Text = "";
			// 
			// lblNEnvases
			// 
			this.lblNEnvases.Location = new System.Drawing.Point(16, 120);
			this.lblNEnvases.Name = "lblNEnvases";
			this.lblNEnvases.Size = new System.Drawing.Size(112, 16);
			this.lblNEnvases.TabIndex = 7;
			this.lblNEnvases.Text = "Envases";
			// 
			// btnSelectMateria
			// 
			this.btnSelectMateria.Location = new System.Drawing.Point(624, 152);
			this.btnSelectMateria.Name = "btnSelectMateria";
			this.btnSelectMateria.Size = new System.Drawing.Size(80, 24);
			this.btnSelectMateria.TabIndex = 35;
			this.btnSelectMateria.Text = "Seleccionar";
			this.btnSelectMateria.Click += new System.EventHandler(this.BtnSelectMateriaClick);
			// 
			// btnAceptaciones
			// 
			this.btnAceptaciones.Location = new System.Drawing.Point(312, 184);
			this.btnAceptaciones.Name = "btnAceptaciones";
			this.btnAceptaciones.Size = new System.Drawing.Size(80, 24);
			this.btnAceptaciones.TabIndex = 20;
			this.btnAceptaciones.Text = "Ver";
			this.btnAceptaciones.Click += new System.EventHandler(this.BtnAceptacionesClick);
			// 
			// btnControlID
			// 
			this.btnControlID.Location = new System.Drawing.Point(632, 88);
			this.btnControlID.Name = "btnControlID";
			this.btnControlID.Size = new System.Drawing.Size(64, 24);
			this.btnControlID.TabIndex = 22;
			this.btnControlID.Text = "Ver";
			// 
			// btnImprimirListado
			// 
			this.btnImprimirListado.Location = new System.Drawing.Point(496, 248);
			this.btnImprimirListado.Name = "btnImprimirListado";
			this.btnImprimirListado.Size = new System.Drawing.Size(104, 24);
			this.btnImprimirListado.TabIndex = 27;
			this.btnImprimirListado.Text = "Imprimir Listado";
			this.btnImprimirListado.Click += new System.EventHandler(this.BtnImprimirListadoClick);
			// 
			// btnNext
			// 
			this.btnNext.Location = new System.Drawing.Point(176, 240);
			this.btnNext.Name = "btnNext";
			this.btnNext.Size = new System.Drawing.Size(32, 24);
			this.btnNext.TabIndex = 30;
			this.btnNext.Text = "->";
			this.btnNext.Click += new System.EventHandler(this.BtnNextClick);
			// 
			// lblProveedorID
			// 
			this.lblProveedorID.Location = new System.Drawing.Point(328, 32);
			this.lblProveedorID.Name = "lblProveedorID";
			this.lblProveedorID.Size = new System.Drawing.Size(112, 16);
			this.lblProveedorID.TabIndex = 2;
			this.lblProveedorID.Text = "Proveedor ID";
			// 
			// lblRegistroID
			// 
			this.lblRegistroID.Location = new System.Drawing.Point(16, 24);
			this.lblRegistroID.Name = "lblRegistroID";
			this.lblRegistroID.Size = new System.Drawing.Size(112, 16);
			this.lblRegistroID.TabIndex = 0;
			this.lblRegistroID.Text = "Registro ID";
			// 
			// txtLote
			// 
			this.txtLote.Location = new System.Drawing.Point(440, 56);
			this.txtLote.Name = "txtLote";
			this.txtLote.Size = new System.Drawing.Size(176, 20);
			this.txtLote.TabIndex = 13;
			this.txtLote.Text = "";
			// 
			// btnProveedor
			// 
			this.btnProveedor.Location = new System.Drawing.Point(632, 24);
			this.btnProveedor.Name = "btnProveedor";
			this.btnProveedor.Size = new System.Drawing.Size(64, 24);
			this.btnProveedor.TabIndex = 21;
			this.btnProveedor.Text = "Ver";
			this.btnProveedor.Click += new System.EventHandler(this.BtnProveedorClick);
			// 
			// btnGuardar
			// 
			this.btnGuardar.Location = new System.Drawing.Point(440, 184);
			this.btnGuardar.Name = "btnGuardar";
			this.btnGuardar.Size = new System.Drawing.Size(104, 24);
			this.btnGuardar.TabIndex = 24;
			this.btnGuardar.Text = "Guardar";
			this.btnGuardar.Click += new System.EventHandler(this.BtnGuardarClick);
			// 
			// txtRegistroID
			// 
			this.txtRegistroID.Location = new System.Drawing.Point(128, 24);
			this.txtRegistroID.Name = "txtRegistroID";
			this.txtRegistroID.Size = new System.Drawing.Size(176, 20);
			this.txtRegistroID.TabIndex = 10;
			this.txtRegistroID.Text = "";
			// 
			// btnLast
			// 
			this.btnLast.Location = new System.Drawing.Point(208, 240);
			this.btnLast.Name = "btnLast";
			this.btnLast.Size = new System.Drawing.Size(32, 24);
			this.btnLast.TabIndex = 31;
			this.btnLast.Text = "->|";
			this.btnLast.Click += new System.EventHandler(this.BtnLastClick);
			// 
			// txtNEnvases
			// 
			this.txtNEnvases.Location = new System.Drawing.Point(128, 120);
			this.txtNEnvases.Name = "txtNEnvases";
			this.txtNEnvases.Size = new System.Drawing.Size(176, 20);
			this.txtNEnvases.TabIndex = 17;
			this.txtNEnvases.Text = "";
			// 
			// lblLote
			// 
			this.lblLote.Location = new System.Drawing.Point(328, 56);
			this.lblLote.Name = "lblLote";
			this.lblLote.Size = new System.Drawing.Size(104, 16);
			this.lblLote.TabIndex = 3;
			this.lblLote.Text = "Lote";
			// 
			// txtFechaCaducidad
			// 
			this.txtFechaCaducidad.Location = new System.Drawing.Point(128, 152);
			this.txtFechaCaducidad.Name = "txtFechaCaducidad";
			this.txtFechaCaducidad.Size = new System.Drawing.Size(176, 20);
			this.txtFechaCaducidad.TabIndex = 18;
			this.txtFechaCaducidad.Text = "";
			// 
			// lblDOE
			// 
			this.lblDOE.Location = new System.Drawing.Point(16, 56);
			this.lblDOE.Name = "lblDOE";
			this.lblDOE.Size = new System.Drawing.Size(112, 16);
			this.lblDOE.TabIndex = 1;
			this.lblDOE.Text = "D.O.E";
			// 
			// txtCantidad
			// 
			this.txtCantidad.Location = new System.Drawing.Point(128, 88);
			this.txtCantidad.Name = "txtCantidad";
			this.txtCantidad.Size = new System.Drawing.Size(176, 20);
			this.txtCantidad.TabIndex = 16;
			this.txtCantidad.Text = "";
			// 
			// lblMateriaID
			// 
			this.lblMateriaID.Location = new System.Drawing.Point(320, 152);
			this.lblMateriaID.Name = "lblMateriaID";
			this.lblMateriaID.Size = new System.Drawing.Size(120, 16);
			this.lblMateriaID.TabIndex = 33;
			this.lblMateriaID.Text = "Materia ID";
			// 
			// btnImprimirFicha
			// 
			this.btnImprimirFicha.Location = new System.Drawing.Point(552, 184);
			this.btnImprimirFicha.Name = "btnImprimirFicha";
			this.btnImprimirFicha.Size = new System.Drawing.Size(104, 24);
			this.btnImprimirFicha.TabIndex = 26;
			this.btnImprimirFicha.Text = "Imprimir";
			this.btnImprimirFicha.Click += new System.EventHandler(this.BtnImprimirFichaClick);
			// 
			// lblFechaCaducidad
			// 
			this.lblFechaCaducidad.Location = new System.Drawing.Point(16, 152);
			this.lblFechaCaducidad.Name = "lblFechaCaducidad";
			this.lblFechaCaducidad.Size = new System.Drawing.Size(112, 16);
			this.lblFechaCaducidad.TabIndex = 8;
			this.lblFechaCaducidad.Text = "Fecha de caducidad";
			// 
			// txtControlID
			// 
			this.txtControlID.Location = new System.Drawing.Point(440, 88);
			this.txtControlID.Name = "txtControlID";
			this.txtControlID.Size = new System.Drawing.Size(176, 20);
			this.txtControlID.TabIndex = 14;
			this.txtControlID.Text = "";
			// 
			// btnBorrar
			// 
			this.btnBorrar.Location = new System.Drawing.Point(552, 216);
			this.btnBorrar.Name = "btnBorrar";
			this.btnBorrar.Size = new System.Drawing.Size(104, 24);
			this.btnBorrar.TabIndex = 25;
			this.btnBorrar.Text = "Borrar";
			this.btnBorrar.Click += new System.EventHandler(this.BtnBorrarClick);
			// 
			// lblPos
			// 
			this.lblPos.Location = new System.Drawing.Point(120, 248);
			this.lblPos.Name = "lblPos";
			this.lblPos.Size = new System.Drawing.Size(56, 16);
			this.lblPos.TabIndex = 32;
			this.lblPos.Text = "0 de 0";
			this.lblPos.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// btnPrev
			// 
			this.btnPrev.Location = new System.Drawing.Point(88, 240);
			this.btnPrev.Name = "btnPrev";
			this.btnPrev.Size = new System.Drawing.Size(32, 24);
			this.btnPrev.TabIndex = 29;
			this.btnPrev.Text = "<-";
			this.btnPrev.Click += new System.EventHandler(this.BtnPrevClick);
			// 
			// btnFirst
			// 
			this.btnFirst.Location = new System.Drawing.Point(56, 240);
			this.btnFirst.Name = "btnFirst";
			this.btnFirst.Size = new System.Drawing.Size(32, 24);
			this.btnFirst.TabIndex = 28;
			this.btnFirst.Text = "|<-";
			this.btnFirst.Click += new System.EventHandler(this.BtnFirstClick);
			// 
			// txtAceptacionID
			// 
			this.txtAceptacionID.Location = new System.Drawing.Point(128, 184);
			this.txtAceptacionID.Name = "txtAceptacionID";
			this.txtAceptacionID.Size = new System.Drawing.Size(176, 20);
			this.txtAceptacionID.TabIndex = 19;
			this.txtAceptacionID.Text = "";
			// 
			// lblFechaRecepcion
			// 
			this.lblFechaRecepcion.Location = new System.Drawing.Point(328, 120);
			this.lblFechaRecepcion.Name = "lblFechaRecepcion";
			this.lblFechaRecepcion.Size = new System.Drawing.Size(120, 24);
			this.lblFechaRecepcion.TabIndex = 5;
			this.lblFechaRecepcion.Text = "Fecha de Recepcion";
			// 
			// lblControlID
			// 
			this.lblControlID.Location = new System.Drawing.Point(328, 88);
			this.lblControlID.Name = "lblControlID";
			this.lblControlID.Size = new System.Drawing.Size(112, 16);
			this.lblControlID.TabIndex = 4;
			this.lblControlID.Text = "Control ID";
			// 
			// lblAceptacionID
			// 
			this.lblAceptacionID.Location = new System.Drawing.Point(16, 184);
			this.lblAceptacionID.Name = "lblAceptacionID";
			this.lblAceptacionID.Size = new System.Drawing.Size(112, 16);
			this.lblAceptacionID.TabIndex = 9;
			this.lblAceptacionID.Text = "Aceptacion ID";
			// 
			// lblCantidad
			// 
			this.lblCantidad.Location = new System.Drawing.Point(16, 96);
			this.lblCantidad.Name = "lblCantidad";
			this.lblCantidad.Size = new System.Drawing.Size(112, 16);
			this.lblCantidad.TabIndex = 6;
			this.lblCantidad.Text = "Cantidad";
			// 
			// txtProveedorID
			// 
			this.txtProveedorID.Location = new System.Drawing.Point(440, 24);
			this.txtProveedorID.Name = "txtProveedorID";
			this.txtProveedorID.Size = new System.Drawing.Size(176, 20);
			this.txtProveedorID.TabIndex = 12;
			this.txtProveedorID.Text = "";
			// 
			// MateriasForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(714, 287);
			this.Controls.Add(this.btnSelectMateria);
			this.Controls.Add(this.txtMateriaID);
			this.Controls.Add(this.lblMateriaID);
			this.Controls.Add(this.lblPos);
			this.Controls.Add(this.btnLast);
			this.Controls.Add(this.btnNext);
			this.Controls.Add(this.btnPrev);
			this.Controls.Add(this.btnFirst);
			this.Controls.Add(this.btnImprimirListado);
			this.Controls.Add(this.btnImprimirFicha);
			this.Controls.Add(this.btnBorrar);
			this.Controls.Add(this.btnGuardar);
			this.Controls.Add(this.btnNuevo);
			this.Controls.Add(this.btnControlID);
			this.Controls.Add(this.btnProveedor);
			this.Controls.Add(this.btnAceptaciones);
			this.Controls.Add(this.txtAceptacionID);
			this.Controls.Add(this.txtFechaCaducidad);
			this.Controls.Add(this.txtNEnvases);
			this.Controls.Add(this.txtCantidad);
			this.Controls.Add(this.txtFechaRecepcion);
			this.Controls.Add(this.txtControlID);
			this.Controls.Add(this.txtLote);
			this.Controls.Add(this.txtProveedorID);
			this.Controls.Add(this.txtDOE);
			this.Controls.Add(this.txtRegistroID);
			this.Controls.Add(this.lblAceptacionID);
			this.Controls.Add(this.lblFechaCaducidad);
			this.Controls.Add(this.lblNEnvases);
			this.Controls.Add(this.lblCantidad);
			this.Controls.Add(this.lblFechaRecepcion);
			this.Controls.Add(this.lblControlID);
			this.Controls.Add(this.lblLote);
			this.Controls.Add(this.lblProveedorID);
			this.Controls.Add(this.lblDOE);
			this.Controls.Add(this.lblRegistroID);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "MateriasForm";
			this.Text = "Registro";
			this.Load += new System.EventHandler(this.MateriasFormLoad);
			this.ResumeLayout(false);
		}
		#endregion
		void MateriasFormLoad(object sender, System.EventArgs e)
		{
			this.CargarConfiguracionDatabase();
			AlertaLocal.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");
			if ( this.Conectar() )
			{
				this.RecPosition = 0;
				this.CargarComandoUpdate();
				this.CargarComandoInsert();
				this.CargarComandoDelete();
				this.RecCount = ds.Tables[0].Rows.Count;
				
			    MostrarPosicion();
			    this.CargarRegistro(this.RecPosition);
			}

		}
		
		void MostrarPosicion(){
			this.lblPos.Text = (this.RecPosition+1).ToString() + " de " + this.RecCount.ToString();
		}

		void CargarRegistro( int numero){
			
			
			if( numero >=0 && numero < ds.Tables[0].Rows.Count)
			{
				string[] res;
				this.txtRegistroID.Text = ds.Tables[0].Rows[numero]["RegistroID"].ToString();
				this.txtMateriaID.Text = ds.Tables[0].Rows[numero]["MateriaID"].ToString();
				this.txtProveedorID.Text = ds.Tables[0].Rows[numero]["ProveedorID"].ToString();
				this.txtLote.Text = ds.Tables[0].Rows[numero]["Lote"].ToString();
				this.txtControlID.Text = ds.Tables[0].Rows[numero]["ControlID"].ToString();
				this.txtFechaRecepcion.Text = ds.Tables[0].Rows[numero]["FechaRecepcion"].ToString();
				this.txtCantidad.Text = ds.Tables[0].Rows[numero]["Cantidad"].ToString();
				this.txtNEnvases.Text = ds.Tables[0].Rows[numero]["NEnvases"].ToString();
				this.txtFechaCaducidad.Text = ds.Tables[0].Rows[numero]["FechaCaducidad"].ToString();
				this.txtAceptacionID.Text = ds.Tables[0].Rows[numero]["AceptacionID"].ToString();
				res = Dispensacion_rutinas.get_componente_details("host="+this.dbhost+";port=" + this.dbport + ";user id="+this.dbuser+";password="+this.dbpasoteword+ ";database=formulacion", Convert.ToInt32(ds.Tables[0].Rows[numero]["MateriaID"]));
				this.txtDOE.Text = res[0];
			}
		}

		void BtnProveedorClick(object sender, System.EventArgs e)
		{
			try{
				ProveedoresForm prvdlg;
				int prvid;
				prvid = Convert.ToInt32 (this.txtProveedorID.Text );
				if( prvid !=0)
				prvdlg = new ProveedoresForm(this.currentlevel, prvid);
				else
				prvdlg = new ProveedoresForm(this.currentlevel);
				prvdlg.ShowDialog();
				this.txtProveedorID.Text = prvdlg.getcurrentid().ToString();
				prvdlg.Dispose();
				
			}catch(Exception ex){
				FM_Errores.MostrarError("MateriaRegistroForm","No se puede abrir la ventana de proveedores",ex);
			}

		}
		
		void BtnAceptacionesClick(object sender, System.EventArgs e)
		{
			try{
				int acid;
				AceptacionesForm af;		
				acid = Convert.ToInt32 (this.txtAceptacionID.Text );
				if( acid !=0)
					af = new AceptacionesForm(this.currentlevel, acid);
				else
					af = new AceptacionesForm(this.currentlevel, Convert.ToInt32( ds.Tables[0].Rows[this.RecPosition]["AceptacionID"]));
			af.ShowDialog();
			af.Dispose();
			}catch(Exception ex){
				FM_Errores.MostrarError("MostrarAceptaciones","No se puede mostrar el visor de aceptaciones",ex);
			}

		}
		
		void BtnPrevClick(object sender, System.EventArgs e)
		{
			if( this.RecPosition > 0)
			this.RecPosition--;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
		}
		
		void BtnFirstClick(object sender, System.EventArgs e)
		{
			this.RecPosition = 0;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);

		}
		
		void BtnNextClick(object sender, System.EventArgs e)
		{
			if( this.RecPosition < this.RecCount-1)
			this.RecPosition++;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
		}
		
		void BtnLastClick(object sender, System.EventArgs e)
		{
			this.RecPosition = this.RecCount-1;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
		}
		
		void BtnGuardarClick(object sender, System.EventArgs e)
		{
			int l; // Nivel para guardar
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(123); // Modulo 12: Registro materias, accion 3: Modificar
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar modificar los datos del registro de materias primas con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite modificar los datos");
				return;
			}
			
			GuardarRegistro(this.RecPosition);
			GuardarModificaciones();
		}
		
		void GuardarModificaciones()
		{
			
			try
    			{
        		int Modificaciones = 0; 
        			Modificaciones = adap.Update(ds,"Registro");
        			ds.Clear();
        			adap.Fill(ds,"Registro");
        			this.RecPosition=0;
        			this.RecCount = ds.Tables[0].Rows.Count;
        			this.CargarRegistro (this.RecPosition );
        			this.MostrarPosicion();
        			FM_Errores.MostrarAviso("Actualizacion correcta","Actualizados "+Modificaciones+" registros");
        			
				}catch (Exception ex){
					FM_Errores.MostrarError("Actualizacion","Error actualizando datos",ex);
        	    }
			
		}

		
		void GuardarRegistro( int numero){
			
			try{
			ds.Tables[0].Rows[numero].BeginEdit();
			ds.Tables[0].Rows[numero]["RegistroID"] = this.txtRegistroID.Text;
			ds.Tables[0].Rows[numero]["MateriaID"] = this.txtMateriaID.Text;
			ds.Tables[0].Rows[numero]["ProveedorID"] = this.txtProveedorID.Text;
			ds.Tables[0].Rows[numero]["Lote"] = this.txtLote.Text;
			ds.Tables[0].Rows[numero]["ControlID"] = this.txtControlID.Text;
			ds.Tables[0].Rows[numero]["FechaRecepcion"] = this.txtFechaRecepcion.Text;
			ds.Tables[0].Rows[numero]["Cantidad"] = this.txtCantidad.Text;
			ds.Tables[0].Rows[numero]["NEnvases"] = this.txtNEnvases.Text;
			ds.Tables[0].Rows[numero]["FechaCaducidad"] = this.txtFechaCaducidad.Text;
			ds.Tables[0].Rows[numero]["AceptacionID"] = this.txtAceptacionID.Text;
			ds.Tables[0].Rows[numero].EndEdit();
			}catch(Exception ex){
				FM_Errores.MostrarError("MateriasRegistroForm","No se puede modificar el registro",ex);
			}

			
			
		}

		void Borrado(object sender, System.Data.DataRowChangeEventArgs e)
		{
			DataRow[] pendientes;
			try{
			pendientes = ds.Tables[0].Select("", "", DataViewRowState.Deleted);
			FM_Errores.MostrarAviso("Borrado","Se han borrado " + adap.Update(pendientes).ToString() + " registros");
					ds.Clear();
        			adap.Fill(ds,"Registro");
        			this.RecPosition=0;
        			this.RecCount = ds.Tables[0].Rows.Count;
        			this.CargarRegistro (this.RecPosition );
        			this.MostrarPosicion();

			}catch(Exception ex){
				FM_Errores.MostrarError("MateriasRegistroForm","No se puede borrar",ex);
			}
		}
		
		void BtnBorrarClick(object sender, System.EventArgs e)
		{
			int l; // Nivel para borrar
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(121); // Modulo 12: registro materias primas, accion 3: Borrar
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar borrar datos del registro de materias primas con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite borrar datos");
				return;
			}

			if (MessageBox.Show("Esta seguro?", "Confirmacin", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
				return;
			
			try{
			ds.Tables[0].RowDeleted += new System.Data.DataRowChangeEventHandler(Borrado);
			ds.Tables["Registro"].Rows.RemoveAt( this.RecPosition);
			}catch(Exception ex){
				FM_Errores.MostrarError("MateriasRegistroForm","No se puede borrar el registro",ex);
			}
			
		}
		
		void BtnNuevoClick(object sender, System.EventArgs e)
		{
			int l; // Nivel para nuevo
			try{
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(122); // Modulo 12: registro materias, accion 2:Nuevo
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar aadir datos al registro de materias primas con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite aadir datos");
				return;
			}

			object[] nr = new Object[ds.Tables[0].Columns.Count];
			nr[1] = 0;
			nr[2] = 0;
			nr[4] = 0;
			
			ds.Tables[0].Rows.Add(nr);
			this.RecCount = ds.Tables[0].Rows.Count;
			this.RecPosition = this.RecCount-1;
			
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
			}catch(Exception ex){
				FM_Errores.MostrarError("Nuevo Regitro","No se puede introducir un nuevo registro",ex);
			}
		}
		
		private void ImprimirListado(int from, int dest)
		{
			try{
			Formulacion.Impresiones docMaterial = new Formulacion.Impresiones();
			PrintPreviewDialog prevDialog = new PrintPreviewDialog();
			PrintDialog prdialog = new PrintDialog();
			
			docMaterial.ImprimirCabezera();
			docMaterial.NuevoTexto("Listado del registro de materias primas.");
			

			
			for(int i=from ; i<dest; ++i)
			{
				string[] res;
				res = Dispensacion_rutinas.get_componente_details("host="+this.dbhost+";port=" + this.dbport + ";user id="+this.dbuser+";password="+this.dbpasoteword+ ";database=formulacion", Convert.ToInt32(ds.Tables[0].Rows[i]["MateriaID"]));
			
			docMaterial.NuevaLinea();
			docMaterial.NuevoTexto("Registro ID:" + ds.Tables[0].Rows[i]["RegistroID"].ToString());
			docMaterial.NuevoTexto("Materia ID: " + ds.Tables[0].Rows[i]["MateriaID"].ToString());
			docMaterial.NuevoTexto("D.O.E: " + res[0]);
			docMaterial.NuevoTexto("Proveedor ID: " + ds.Tables[0].Rows[i]["ProveedorID"].ToString());
			docMaterial.NuevoTexto("Lote: " +ds.Tables[0].Rows[i]["Lote"].ToString());
			docMaterial.NuevoTexto("Control ID: " +ds.Tables[0].Rows[i]["ControlID"].ToString());
			docMaterial.NuevoTexto("Fecha de Recepcion: " + ds.Tables[0].Rows[i]["FechaRecepcion"].ToString());
			docMaterial.NuevoTexto("Cantidad: " + ds.Tables[0].Rows[i]["Cantidad"].ToString() + " " + res[1] );
			docMaterial.NuevoTexto("Numero de envases: " + ds.Tables[0].Rows[i]["NEnvases"].ToString());
			docMaterial.NuevoTexto("Fecha de Caducidad: " + ds.Tables[0].Rows[i]["FechaCaducidad"].ToString());
			docMaterial.NuevoTexto("Identificado de aceptacion en registro: " + ds.Tables[0].Rows[i]["AceptacionID"].ToString());
			docMaterial.NuevoTexto("");
			}
			
			prevDialog.Document = docMaterial;
			prdialog.Document = docMaterial;
			
			docMaterial.PrintPage += new PrintPageEventHandler(docMaterial.ImprimirElementos);
			docMaterial.BeginPrint += new PrintEventHandler (docMaterial.Reajustar);
			
			// Esto esta por ser configurable en fichero XML o DB
			// docMaterial.MuestraPrefsPagina();
			
			
			// Esto tambien deberia ser configurable
			prevDialog.Text = "Previsualizacion del listado del registro de materias primas";
			prevDialog.ShowDialog();
			
			if (prdialog.ShowDialog()== DialogResult.OK)
			{
				docMaterial.Print();
			}

			
			}catch(Exception ex){
				FM_Errores.MostrarError("Impresion","No se puede imprimir el listado",ex);
			}

		}
		
		
		
		void BtnImprimirFichaClick(object sender, System.EventArgs e)
		{
			this.ImprimirListado(this.RecPosition,this.RecPosition+1);
		}
		
		void BtnImprimirListadoClick(object sender, System.EventArgs e)
		{
			this.ImprimirListado(0,ds.Tables[0].Rows.Count);
		}
		
		void BtnSelectMateriaClick(object sender, System.EventArgs e)
		{
			try{
				MateriasList mtl1;
				int mtid;
				mtid = Convert.ToInt32 (this.txtMateriaID.Text );
				if( mtid !=0)
				mtl1 = new MateriasList(this.currentlevel, mtid);
				else
				mtl1 = new MateriasList(this.currentlevel);
				mtl1.ShowDialog();
				this.txtMateriaID.Text = mtl1.getcurrentid().ToString();
				mtl1.Dispose();
				
			}catch(Exception ex){
				FM_Errores.MostrarError("MateriaRegistroForm","No se puede abrir la ventana de materias primas",ex);
			}

		}
		
	}
}
